==> haskell-unixutils-1.54.1-95-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-IZgHUy55NJgJNOQoWeYCz6
key: Unixutils-1.54.1-IZgHUy55NJgJNOQoWeYCz6
license: BSD-3-Clause
maintainer: jeremy@n-heptane.com
author: Jeremy Shaw, David Fox
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
abi: 569c3628c377a960cd0d5cfb7ee3083c
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
import-dirs: /usr/lib/ghc-8.6.5/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-IZgHUy55NJgJNOQoWeYCz6
extra-libraries:
    crypt
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk filepath-1.4.2.1 mtl-2.2.2
    process-1.6.5.0 process-extras-0.7.4-FcD2hGU95nxlXm4Ejp6Qc
    pureMD5-2.1.3-JGiaZFjxwvx3ZBe3kp9Wvj
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi unix-2.7.2.2
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.1-96-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-6tgjFmVlH2iJlUhHG53Gwt
key: Unixutils-1.54.1-6tgjFmVlH2iJlUhHG53Gwt
license: BSD-3-Clause
maintainer: jeremy@n-heptane.com
author: Jeremy Shaw, David Fox
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
abi: 096699f78e90239af0cf3f67f7b0f6b6
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
import-dirs: /usr/lib/ghc-8.6.5/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-6tgjFmVlH2iJlUhHG53Gwt
extra-libraries:
    crypt
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk filepath-1.4.2.1 mtl-2.2.2
    process-1.6.5.0 process-extras-0.7.4-LGmJvrQ15Oz12Pl7wLOmJe
    pureMD5-2.1.3-JGiaZFjxwvx3ZBe3kp9Wvj
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi unix-2.7.2.2
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
